from django.apps import AppConfig


class OperationlogConfig(AppConfig):
    default_auto_field = "django.db.models.BigAutoField"
    name = "drf_operation_log"
